@@ -23,6 +23,12 @@
 
 #ifdef USE_GSSAPI
 
+#ifdef USE_GSS
+
+#include <gss.h>
+
+#else /* MIT GSSAPI */
+
 #ifdef HAVE_GSSAPI_H
 #include <gssapi.h>
 #endif
@@ -32,8 +38,7 @@
 #ifdef HAVE_GSSAPI_GSSAPI_GENERIC_H
 #include <gssapi/gssapi_generic.h>
 #endif
-#ifndef HAVE_GSS_C_NT_HOSTBASED_SERVICE
-#define GSS_C_NT_HOSTBASED_SERVICE gss_nt_service_name
+
 #endif
 
 #ifdef HAVE_NETINET_IN_H
@@ -278,7 +283,7 @@ _gsasl_gssapi_client_finish (Gsasl_session_ctx * sctx, void *mech_data)
 
   maj_stat = gss_release_name (&min_stat, &state->service);
   if (state->context != GSS_C_NO_CONTEXT)
-    maj_stat = gss_delete_sec_context (&min_stat, state->context,
+    maj_stat = gss_delete_sec_context (&min_stat, &state->context,
 				       GSS_C_NO_BUFFER);
 
   free (state);
