@@ -1,5 +1,5 @@
 /* login.h	header file for non-standard SASL mechanism LOGIN
- * Copyright (C) 2002  Simon Josefsson
+ * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -22,6 +22,10 @@
 #ifndef _LOGIN_H
 #define _LOGIN_H
 
+#include "internal.h"
+
+#ifdef USE_LOGIN
+
 #define _GSASL_LOGIN_NAME "LOGIN"
 
 extern int _gsasl_login_client_init (Gsasl_ctx * ctx);
@@ -48,4 +52,6 @@ extern int _gsasl_login_server_step (Gsasl_session_ctx * sctx,
 extern int _gsasl_login_server_finish (Gsasl_session_ctx * sctx,
 				       void *mech_data);
 
+#endif /* USE_LOGIN */
+
 #endif /* _LOGIN_H */
