@@ -1,5 +1,5 @@
 /* securid.h	header file for SASL mechanism SECURID as defined in RFC 2808
- * Copyright (C) 2002  Simon Josefsson
+ * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -22,6 +22,10 @@
 #ifndef _SECURID_H
 #define _SECURID_H
 
+#include "internal.h"
+
+#ifdef USE_SECURID
+
 #define _GSASL_SECURID_NAME "SECURID"
 
 extern int _gsasl_securid_client_init (Gsasl_ctx * ctx);
@@ -48,4 +52,6 @@ extern int _gsasl_securid_server_step (Gsasl_session_ctx * sctx,
 extern int _gsasl_securid_server_finish (Gsasl_session_ctx * sctx,
 					 void *mech_data);
 
+#endif /* USE_SECURID */
+
 #endif /* _SECURID_H */
